==> apache-karaf-4.1.7-src.zip: apache-karaf-4.1.7/deployer/spring/src/main/java/org/apache/karaf/deployer/spring/osgi/Activator.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.karaf.deployer.spring.osgi;

import java.util.Hashtable;

import org.apache.felix.fileinstall.ArtifactListener;
import org.apache.felix.fileinstall.ArtifactUrlTransformer;
import org.apache.karaf.deployer.spring.SpringDeploymentListener;
import org.apache.karaf.deployer.spring.SpringURLHandler;
import org.apache.karaf.util.tracker.BaseActivator;
import org.apache.karaf.util.tracker.annotation.Services;
import org.osgi.service.url.URLStreamHandlerService;

@Services
public class Activator extends BaseActivator {

    @Override
    protected void doStart() throws Exception {
        Hashtable<String, Object> props = new Hashtable<String, Object>();
        props.put("url.handler.protocol", "spring");
        register(URLStreamHandlerService.class, new SpringURLHandler(), props);
        register(new Class[] { ArtifactUrlTransformer.class, ArtifactListener.class },
                 new SpringDeploymentListener());
    }

}

==> apache-karaf-4.4.6-src.zip: apache-karaf-4.4.6/deployer/spring/src/main/java/org/apache/karaf/deployer/spring/osgi/Activator.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.karaf.deployer.spring.osgi;

import java.util.Hashtable;

import org.apache.felix.fileinstall.ArtifactListener;
import org.apache.felix.fileinstall.ArtifactUrlTransformer;
import org.apache.karaf.deployer.spring.SpringDeploymentListener;
import org.apache.karaf.deployer.spring.SpringURLHandler;
import org.apache.karaf.util.tracker.BaseActivator;
import org.apache.karaf.util.tracker.annotation.Services;
import org.osgi.service.url.URLStreamHandlerService;

@Services
public class Activator extends BaseActivator {

    @Override
    protected void doStart() throws Exception {
        Hashtable<String, Object> props = new Hashtable<>();
        props.put("url.handler.protocol", "spring");
        register(URLStreamHandlerService.class, new SpringURLHandler(), props);
        register(new Class[] { ArtifactUrlTransformer.class, ArtifactListener.class },
                 new SpringDeploymentListener());
    }

}
